@@ -1,10 +1,11 @@
 package RDF::KML::Exporter;
 
 use 5.010;
-use common::sense;
+use strict;
 
 use Geo::GoogleEarth::Pluggable;
-use RDF::TrineShortcuts qw[:all];
+use PerlX::Maybe;
+use RDF::TrineX::Functions -shortcuts_nodes;
 use Scalar::Util qw[blessed];
 
 sub GEO  { return 'http://www.w3.org/2003/01/geo/wgs84_pos#' . shift; }
@@ -12,7 +13,7 @@ sub RDFS { return 'http://www.w3.org/2000/01/rdf-schema#' . shift; }
 
 use namespace::clean;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 sub new
 {
@@ -23,7 +24,7 @@ sub new
 sub export_kml
 {
 	my ($self, $model, %options) = @_;
-	$model = RDF::TrineShortcuts::rdf_parse($model)
+	$model = rdf_parse($model)
 		unless blessed($model) && $model->isa('RDF::Trine::Model');
 
 	my $kml = Geo::GoogleEarth::Pluggable->new;
@@ -31,46 +32,45 @@ sub export_kml
 	my @subjects = $model->subjects;
 	S: foreach my $s (@subjects)
 	{
-		my @latitudes  = grep
-				{ $_->is_literal }
-				$model->objects_for_predicate_list($s,
-					rdf_resource(GEO('lat')),
-					);
-		next S unless @latitudes;
-		my $lat  = flatten_node($latitudes[0]);
+		my ($lat) =
+			map  { $_->literal_value }
+			grep { $_->is_literal }
+			$model->objects_for_predicate_list($s,
+				rdf_resource(GEO('lat')),
+			);
+		defined $lat or next S;
 		
-		my @longitudes = grep
-				{ $_->is_literal }
-				$model->objects_for_predicate_list($s,
-					rdf_resource(GEO('long')),
-					);
-		next S unless @longitudes;
-		my $long = flatten_node($longitudes[0]);
+		my ($long) =
+			map  { $_->literal_value }
+			grep { $_->is_literal }
+			$model->objects_for_predicate_list($s,
+				rdf_resource(GEO('long')),
+			);
+		defined $long or next S;
 		
-		my @altitudes = grep
-				{ $_->is_literal }
-				$model->objects_for_predicate_list($s,
-					rdf_resource(GEO('alt')),
-					);
-		my $alt = flatten_node($altitudes[0], passthrough_undef => 1);
-
-		my @labels = grep
-			{ $_->is_literal }
+		my ($alt) =
+			map  { $_->literal_value }
+			grep { $_->is_literal }
+			$model->objects_for_predicate_list($s,
+				rdf_resource(GEO('alt')),
+			);
+		
+		my ($name) =
+			map  { $_->literal_value }
+			grep { $_->is_literal }
 			$model->objects_for_predicate_list($s,
 				rdf_resource('http://www.geonames.org/ontology#name'),
 				rdf_resource('http://www.w3.org/2004/02/skos/core#prefLabel'),
 				rdf_resource(RDFS('label')),
 				rdf_resource('http://xmlns.com/foaf/0.1/name'),
-#				rdf_resource('http://www.w3.org/2004/02/skos/core#altLabel'),
-#				rdf_resource('http://www.w3.org/2004/02/skos/core#notation'),
-				);
-		my $label = flatten_node($labels[0], passthrough_undef => 1);
-
-		my %info = (lat=>$lat, lon=>$long);
-		$info{name} ||= $label if defined $label;
-		$info{alt}  ||= $alt   if defined $alt;
+			);
 		
-		$kml->Point(%info);
+		$kml->Point(
+			      lat  => $lat,
+			      lon  => $long,
+			maybe alt  => $alt,
+			maybe name => $name,
+		);
 	}
 	
 	return $kml;
@@ -118,7 +118,7 @@ Returns a KML document including all the locations in the input,
 in no particular order.
 
 The input may be a URI, file name, L<RDF::Trine::Model> or anything else
-that can be handled by the C<rdf_parse> method of L<RDF::TrineShortcuts>.
+that can be handled by the C<parse> function of L<RDF::TrineX::Functions>.
 
 The returned object is an L<Geo::GoogleEarth::Pluggable> instance, which
 can be output as XML using its C<render> method.
@@ -133,21 +133,23 @@ rdfs:label.
 
 =head1 SEE ALSO
 
-L<HTML::Microformats>, L<RDF::TrineShortcuts>,
+L<HTML::Microformats>, L<RDF::TrineX::Functions>,
 L<Geo::GoogleEarth::Pluggable>.
 
 L<http://www.w3.org/2003/01/geo/wgs84_pos#>.
 
 L<http://www.perlrdf.org/>.
 
-=head1 AUTHOR
+=head1 COPYRIGHT AND LICENCE
 
-Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
+This software is copyright (c) 2011-2012 by Toby Inkster.
 
-=head1 COPYRIGHT
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-Copyright 2011 Toby Inkster
+=head1 DISCLAIMER OF WARRANTIES
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
